@@ -6,9 +6,10 @@ class Bulk(Entity):
     :type name: str
     :type sort: int
     :type type_id: int
+    :type settlement_fact: bool
     """
 
-    def __init__(self, id_or_dict, name: str = None, sort: int = None, type_id: int = 0):
+    def __init__(self, id_or_dict, name: str = None, sort: int = None, type_id: int = 0, settlement_fact: bool = None):
         super().__init__(id_or_dict)
         if type(id_or_dict) is dict:
             name = id_or_dict.get('name')
@@ -23,3 +24,6 @@ class Bulk(Entity):
         if type(type_id) is not int:
             raise ValueError
         self.type_id = type_id
+        if type(settlement_fact) is not bool:
+            raise ValueError
+        self.settlement_fact = settlement_fact
